summaryrefslogtreecommitdiffstats
path: root/kmymoney2/views/kcategoriesview.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/views/kcategoriesview.h')
-rw-r--r--kmymoney2/views/kcategoriesview.h23
1 files changed, 12 insertions, 11 deletions
diff --git a/kmymoney2/views/kcategoriesview.h b/kmymoney2/views/kcategoriesview.h
index 4a6ad3c..d37e74d 100644
--- a/kmymoney2/views/kcategoriesview.h
+++ b/kmymoney2/views/kcategoriesview.h
@@ -45,7 +45,7 @@ class KListViewSearchLineWidget;
* @author Michael Edwardes, Thomas Baumgart
*
* While named "categories view", this view actually displays all accounts
- * that are children of the global "Income" and "Expense" accounts. Even though
+ * that are tqchildren of the global "Income" and "Expense" accounts. Even though
* categories are internally just accounts as well, the distinction between
* categories and accounts in the user interface is done for better
* usability and clarity.
@@ -63,8 +63,9 @@ class KListViewSearchLineWidget;
class KCategoriesView : public KCategoriesViewDecl
{
Q_OBJECT
+ TQ_OBJECT
public:
- KCategoriesView(QWidget *parent=0, const char *name=0);
+ KCategoriesView(TQWidget *tqparent=0, const char *name=0);
virtual ~KCategoriesView();
@@ -78,15 +79,15 @@ public slots:
void show(void);
/**
- * Override the base class behaviour to restore the layout. Do not
- * do this in show() because show() itself may change the layout
+ * Override the base class behaviour to restore the tqlayout. Do not
+ * do this in show() because show() itself may change the tqlayout
* in undesired ways.
*/
void polish(void);
protected:
void loadAccounts(void);
- bool loadSubAccounts(KMyMoneyAccountTreeItem* parent, const QStringList& accountList);
+ bool loadSubAccounts(KMyMoneyAccountTreeItem* tqparent, const TQStringList& accountList);
protected slots:
void slotUpdateProfit(void);
@@ -99,7 +100,7 @@ private:
*
* @param type account type as defined in MyMoneyAccount::accountTypeE
*/
- const QPixmap accountImage(const MyMoneyAccount::accountTypeE type) const;
+ const TQPixmap accountImage(const MyMoneyAccount::accountTypeE type) const;
signals:
/**
@@ -121,16 +122,16 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
* account @p acc to be a subordinate account of @p parent.
*
* @param acc const reference to account to be reparented
* @param parent const reference to new parent account
*/
- void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& parent);
+ void reparent(const MyMoneyAccount& acc, const MyMoneyAccount& tqparent);
private:
- QMap<QString, MyMoneySecurity> m_securityMap;
- QMap<QString, unsigned long> m_transactionCountMap;
+ TQMap<TQString, MyMoneySecurity> m_securityMap;
+ TQMap<TQString, unsigned long> m_transactionCountMap;
KMyMoneyAccountTreeItem* m_incomeItem;
KMyMoneyAccountTreeItem* m_expenseItem;
@@ -121,16 +122,16 @@ signals:
/**
* This signal is emitted, when the user selected to reparent the
- * account @p acc to be a subordinate account of @p parent.
+ * account @p acc to be a subordinate account of @p tqparent.
*
* @param acc const reference to account to be reparented
@@ -121,16 +122,16 @@ signals:
*
* @param acc const reference to account to be reparented
- * @param parent const reference to new parent account
+ * @param tqparent const reference to new tqparent account
*/